/*
 * Copyright (c) 1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *
 * 4. The names "Java Apache Element Construction Set", "Java Apache ECS" and 
 *    "Java Apache Project" must not be used to endorse or promote products 
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called 
 *    "Java Apache Element Construction Set" nor "Java Apache ECS" appear 
 *    in their names without prior written permission of the 
 *    Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *    
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Project. For more information
 * on the Java Apache Project please see <http://java.apache.org/>.
 *
 */
package org.apache.ecs;

/**
    This class creates a &lt;TH&gt; object.
    @version $Id: TH.java,v 1.5 1999/05/06 21:55:02 jonbolt Exp $
    @author <a href="mailto:snagy@servletapi.com">Stephan Nagy</a>
    @author <a href="mailto:jon@clearink.com">Jon S. Stevens</a>
*/
public class TH extends MultiPartElement
{
    /**
        private initializer.
    */
    {
        setElementType("th");
    }

    /**
        Basic constructor.  Use set* methods.
    */
    public TH()
    {
    }

    /**
        Basic Constructor use set* methods.
        @param close.  Print the closing tag or not.
    */
    public TH(boolean close)
    {
        setNeedClosingTag(close);
    }

    /**
        Sets the ABBR="" attribute.
        @param cdata    sets the ABBR="" attribute.
    */
    public TH setAbbr(String cdata)
    {
        addAttribute("abbr",cdata);
        return(this);
    }

    /**
        Sets the AXIS="" attribute
        @param  cdata   sets the AXIS="" attribute
    */
    public TH setAxis(String cdata)
    {
        addAttribute("axis",cdata);
        return(this);
    }

    /**
        Sets the AXES="" attribute
        @param  id_refs list of id's for header cells
    */
    public TH setAxes(String id_refs)
    {
        addAttribute("axes",id_refs);
        return(this);
    }

    /**
        Sets the ROWSPAN="" attribute
        @param  span    Number of rows spaned by cell
    */
    public TH setRowSpan(int span)
    {
        addAttribute("span",Integer.toString(span));
        return(this);
    }

    /**
        Sets the ROWSPAN="" attribute
        @param  span    Number of rows spaned by cell
    */
    public TH setRowSpan(String span)
    {
        addAttribute("span",span);
        return(this);
    }

    /**
        Sets the COLSPAN="" attribute
        @param  span    Number of columns spanned by cell
    */
    public TH setColSpan(int span)
    {
        addAttribute("colspan",Integer.toString(span));
        return(this);
    }

    /**
        Sets the COLSPAN="" attribute
        @param  span    Number of columns spanned by cell
    */
    public TH setColSpan(String span)
    {
        addAttribute("colspan",span);
        return(this);
    }

    /**
        Sets word wrap on or off.
        @param wrap turn word wrap on or off.
    */
    public TH setNoWrap(boolean wrap)
    {
        if ( wrap == true )
            addAttribute("nowrap", NO_ATTRIBUTE_VALUE);
        else
            removeAttribute("nowrap");

        return(this);
    }

    /**
        Supplies user agents with a recommended cell width.  (Pixel Values)
        @param width    how many pixels to make cell
    */
    public TH setWidth(int width)
    {
        addAttribute("width",Integer.toString(width));
        return(this);
    }
    
    /**
        Supplies user agents with a recommended cell width.  (Pixel Values)
        @param width    how many pixels to make cell
    */
    public TH setWidth(String width)
    {
        addAttribute("width",width);
        return(this);
    }

    /**
        Supplies user agents with a recommended cell height.  (Pixel Values)
        @param height    how many pixels to make cell
    */
    public TH setHeight(int height)
    {
        addAttribute("height",Integer.toString(height));
        return(this);
    }

    /**
        Supplies user agents with a recommended cell height.  (Pixel Values)
        @param height    how many pixels to make cell
    */
    public TH setHeight(String height)
    {
        addAttribute("height",height);
        return(this);
    }

    /**
        Sets the ALIGN="" attribute convience variables are provided in the AlignType interface
        @param  align   Sets the ALIGN="" attribute
    */
    public TH setAlign(String align)
    {
        addAttribute("align",align);
        return(this);
    }

    /**
        Sets the VALIGN="" attribute convience variables are provided in the AlignType interface
        @param  valign   Sets the ALIGN="" attribute
    */
    public TH setVAlign(String valign)
    {
        addAttribute("valign",valign);
        return(this);
    }

    /**
        Sets the CHAR="" attribute.
        @param character    the character to use for alignment.
    */
    public TH setChar(String character)
    {
        addAttribute("char",character);
        return(this);
    }

    /**
        Sets the CHAROFF="" attribute.
        @param char_off When present this attribute specifies the offset
        of the first occurrence of the alignment character on each line.
    */
    public TH setCharOff(int char_off)
    {
        addAttribute("charoff",Integer.toString(char_off));
        return(this);
    }

    /**
        Sets the CHAROFF="" attribute.
        @param char_off When present this attribute specifies the offset
        of the first occurrence of the alignment character on each line.
    */
    public TH setCharOff(String char_off)
    {
        addAttribute("charoff",char_off);
        return(this);
    }

    /**
        Sets the BGCOLOR="" attribute
        @param color    sets the background color of the cell.
    */
    public TH setBgColor(String color)
    {
        addAttribute("bgcolor",HtmlColor.convertColor(color));
        return(this);
    }
    /**
        Adds an Element to the element.
        @param  element Adds an Element to the element.
     */
    public TH addElement(Element element)
    {
        addElementToRegistry(element,getFilterState());
        return(this);
    }

    /**
        Adds an Element to the element.
        @param  element Adds an Element to the element.
     */
    public TH addElement(String element)
    {
        addElementToRegistry(element,getFilterState());
        return(this);
    }
} 